<h2 class="title">Sites in Dexy</h2>

<p class="subtitle">How to Use the Website Reporter</p>

Contents:

[TOC]

### The WebsiteReporter

The WebsiteReporter helps you generate a website from your Dexy output. It
helps you do things like apply HTML templates and automatically generate page
navigation.

The WebsiteReporter won't run by default. You need to use the `--reports` command line option to customize which reports dexy runs. If you are making a website, you will probably want the WebsiteReporter to run every time you run dexy, so instead of typing this on the command line each time, you can put it in a config file like this:

<div class="highlight"><pre><a name="dexy.conf-pyg.html-1"></a><span class="c1"># YAML config file for dexy.</span>
<a name="dexy.conf-pyg.html-2"></a><span class="c1"># Options are same as command line options, for more info run &#39;dexy help -on dexy&#39;.</span>
<a name="dexy.conf-pyg.html-3"></a><span class="l-Scalar-Plain">reports</span><span class="p-Indicator">:</span> <span class="s">&#39;ws</span><span class="nv"> </span><span class="s">run&#39;</span>
</pre></div>


This means that only the WebsiteReporter and RunReporter will run, so you won't see the `output/` and `output-long/` directories you're used to. You can always add them to the list if you still want them. You can see a list of all the available reporters like this:

<div class="highlight"><pre><a name="list-reports.sh-shint-pyg.html-1"></a><span class="gp">$</span> dexy reporters
<a name="list-reports.sh-shint-pyg.html-2"></a><span class="go">ALIAS      DIRECTORY            INFO</span>
<a name="list-reports.sh-shint-pyg.html-3"></a><span class="go">long       output-long          Creates complete dexy output with files given long, unique filenames.</span>
<a name="list-reports.sh-shint-pyg.html-4"></a><span class="go">output     output               Creates canonical dexy output with files given short filenames.</span>
<a name="list-reports.sh-shint-pyg.html-5"></a><span class="go">run                            </span>
<a name="list-reports.sh-shint-pyg.html-6"></a><span class="go">ws         output-site          Applies a template to create a website from your dexy output.</span>
</pre></div>


The alias is what you add to the --reports list, which should be a string where each alias is separated by a space.

The WebsiteReporter will copy all non-HTML files to the `output-site/` directory unchanged. When it encounters a HTML file, it will look to see if there is already a header and, if so, it will leave that file alone. If the HTML appears to be just internal page content, then the WebsiteReporter will look for a file named `_template.html` and will apply that template.

### Finding Templates

The WebsiteReporter looks first in the same directory as the file being processed, then it looks in each succeeding parent directory as far up as the project root, until it finds a file named `_template.html`. It uses the first one it finds (i.e. the one closest to the HTML document being processed). If it does not find one, it raises a UserFeedback exception to let you know. You can tell the WebsiteReporter not to try to apply a template by setting the `ws_template` argument to False, as in this example:

<div class="highlight"><pre><a name="dexy.yaml-idio.html-17"></a><span class="l-Scalar-Plain">source</span><span class="p-Indicator">:</span>
<a name="dexy.yaml-idio.html-18"></a>    <span class="p-Indicator">-</span> <span class="l-Scalar-Plain">.txt</span>
<a name="dexy.yaml-idio.html-19"></a>    <span class="p-Indicator">-</span> <span class="l-Scalar-Plain">.md</span>
<a name="dexy.yaml-idio.html-20"></a>    <span class="p-Indicator">-</span> <span class="s">&quot;*/_*.html|pyg|-&quot;</span><span class="p-Indicator">:</span>
<a name="dexy.yaml-idio.html-21"></a>        <span class="p-Indicator">-</span> <span class="l-Scalar-Plain">canon</span> <span class="p-Indicator">:</span> <span class="l-Scalar-Plain">True</span>
<a name="dexy.yaml-idio.html-22"></a>        <span class="p-Indicator">-</span> <span class="l-Scalar-Plain">ws_template</span> <span class="p-Indicator">:</span> <span class="l-Scalar-Plain">False</span>
</pre></div>


You can also specify another file to use as a template, as in this example:

<div class="highlight"><pre><a name="dexy.yaml-idio.html-2"></a><span class="l-Scalar-Plain">docs</span><span class="p-Indicator">:</span>
<a name="dexy.yaml-idio.html-3"></a>    <span class="p-Indicator">-</span> <span class="l-Scalar-Plain">index.html|jinja|markdown|htmlsections</span><span class="p-Indicator">:</span>
<a name="dexy.yaml-idio.html-4"></a>        <span class="p-Indicator">-</span> <span class="l-Scalar-Plain">ws_template</span> <span class="p-Indicator">:</span> <span class="s">&#39;_home_template.html&#39;</span>
<a name="dexy.yaml-idio.html-5"></a>    <span class="p-Indicator">-</span> <span class="l-Scalar-Plain">.md|jinja|markdown</span><span class="p-Indicator">:</span>
<a name="dexy.yaml-idio.html-6"></a>        <span class="p-Indicator">-</span> <span class="l-Scalar-Plain">meta</span>
<a name="dexy.yaml-idio.html-7"></a>        <span class="p-Indicator">-</span> <span class="l-Scalar-Plain">source</span>
</pre></div>


### The content Tag

The templates are jinja templates. Here is a very simple template which only uses a single tag, `content`, to insert the content of the page it is processing:

<div class="highlight"><pre><a name="about--_simple_template.html-pyg.html-1"></a><span class="nt">&lt;html&gt;</span>
<a name="about--_simple_template.html-pyg.html-2"></a>    <span class="nt">&lt;head&gt;</span>
<a name="about--_simple_template.html-pyg.html-3"></a>    <span class="nt">&lt;/head&gt;</span>
<a name="about--_simple_template.html-pyg.html-4"></a>    <span class="nt">&lt;body&gt;</span>
<a name="about--_simple_template.html-pyg.html-5"></a>        {{ content }}
<a name="about--_simple_template.html-pyg.html-6"></a>    <span class="nt">&lt;/body&gt;</span>
<a name="about--_simple_template.html-pyg.html-7"></a><span class="nt">&lt;/html&gt;</span>
</pre></div>


<div class="highlight"><pre><a name="about--simple_content.html-pyg.html-1"></a><span class="nt">&lt;p&gt;</span>This is some simple content.<span class="nt">&lt;/p&gt;</span>
</pre></div>
 [link to page rendered in template](simple_content.html)

If the page content is split into named sections, these sections can be referenced as attributes of `content`.

<div class="highlight"><pre><a name="about--_head_body_template.html-pyg.html-1"></a><span class="nt">&lt;html&gt;</span>
<a name="about--_head_body_template.html-pyg.html-2"></a>    <span class="nt">&lt;head&gt;</span>
<a name="about--_head_body_template.html-pyg.html-3"></a>        {{ content.head }}
<a name="about--_head_body_template.html-pyg.html-4"></a>    <span class="nt">&lt;/head&gt;</span>
<a name="about--_head_body_template.html-pyg.html-5"></a>    <span class="nt">&lt;body&gt;</span>
<a name="about--_head_body_template.html-pyg.html-6"></a>        {{ content.body }}
<a name="about--_head_body_template.html-pyg.html-7"></a>    <span class="nt">&lt;/body&gt;</span>
<a name="about--_head_body_template.html-pyg.html-8"></a><span class="nt">&lt;/html&gt;</span>
</pre></div>


For example, this HTML source is split into sections by the `htmlsections` filter, and then the named sections are placed into the relevant spots in the template.

<div class="highlight"><pre><a name="about--head_body_content.html-pyg.html-1"></a><span class="c">&lt;!-- section &quot;head&quot; --&gt;</span>
<a name="about--head_body_content.html-pyg.html-2"></a><span class="nt">&lt;style </span><span class="na">type=</span><span class="s">&quot;text/css&quot;</span><span class="nt">&gt;</span>
<a name="about--head_body_content.html-pyg.html-3"></a>    <span class="nt">body</span> <span class="p">{</span> <span class="k">background-color</span><span class="o">:</span> <span class="nb">purple</span><span class="p">;</span> <span class="p">}</span>
<a name="about--head_body_content.html-pyg.html-4"></a><span class="nt">&lt;/style&gt;</span>
<a name="about--head_body_content.html-pyg.html-5"></a>
<a name="about--head_body_content.html-pyg.html-6"></a><span class="c">&lt;!-- section &quot;body&quot; --&gt;</span>
<a name="about--head_body_content.html-pyg.html-7"></a><span class="nt">&lt;p&gt;</span>This is the main content!<span class="nt">&lt;/p&gt;</span>
</pre></div>
 [link to page rendered in template](head_body_content.html)

Here is the `dexy.yaml` for these pages:

<div class="highlight"><pre><a name="about--dexy.yaml-idio.html-2"></a><span class="p-Indicator">-</span> <span class="l-Scalar-Plain">simple_content.html</span><span class="p-Indicator">:</span>
<a name="about--dexy.yaml-idio.html-3"></a>    <span class="p-Indicator">-</span> <span class="l-Scalar-Plain">ws_template</span><span class="p-Indicator">:</span> <span class="l-Scalar-Plain">_simple_template.html</span>
<a name="about--dexy.yaml-idio.html-4"></a>
<a name="about--dexy.yaml-idio.html-5"></a><span class="p-Indicator">-</span> <span class="l-Scalar-Plain">head_body_content.html|htmlsections</span><span class="p-Indicator">:</span>
<a name="about--dexy.yaml-idio.html-6"></a>    <span class="p-Indicator">-</span> <span class="l-Scalar-Plain">ws_template</span><span class="p-Indicator">:</span> <span class="l-Scalar-Plain">_head_body_template.html</span>
</pre></div>


### Jinja Templates and Macros

The WebsiteReporter lets you make use of jinja's [template inheritance](http://jinja.pocoo.org/docs/templates/#template-inheritance) and [macros](http://jinja.pocoo.org/docs/templates/#macros). The dexy project root and the directory containing the page being processed are passed to jinja's FileSystemLoader, so you can reference templates and macro files relative to either of these locations.

For this website, we define a `_base.html` template:

<div class="highlight"><pre><a name="_base.html-pyg.html-1"></a>{% from &#39;macros/nav.jinja&#39; import menu with context %}
<a name="_base.html-pyg.html-2"></a><span class="cp">&lt;!DOCTYPE HTML&gt;</span>
<a name="_base.html-pyg.html-3"></a><span class="c">&lt;!--</span>
<a name="_base.html-pyg.html-4"></a><span class="c">Altitude: A responsive HTML5 website template by HTML5Templates.com</span>
<a name="_base.html-pyg.html-5"></a><span class="c">Released for free under the Creative Commons Attribution 3.0 license (html5templates.com/license)</span>
<a name="_base.html-pyg.html-6"></a><span class="c">Visit http://html5templates.com for more great templates or follow us on Twitter @HTML5T</span>
<a name="_base.html-pyg.html-7"></a><span class="c">--&gt;</span>
<a name="_base.html-pyg.html-8"></a><span class="nt">&lt;html&gt;</span>
<a name="_base.html-pyg.html-9"></a>    {% block head -%}
<a name="_base.html-pyg.html-10"></a>    {% include &#39;macros/_header.html&#39; -%}
<a name="_base.html-pyg.html-11"></a>    {% endblock -%}
<a name="_base.html-pyg.html-12"></a>    <span class="nt">&lt;body&gt;</span>
<a name="_base.html-pyg.html-13"></a>        <span class="nt">&lt;div</span> <span class="na">id=</span><span class="s">&quot;wrapper&quot;</span><span class="nt">&gt;</span>
<a name="_base.html-pyg.html-14"></a>            <span class="nt">&lt;div</span> <span class="na">id=</span><span class="s">&quot;header-wrapper&quot;</span><span class="nt">&gt;</span>
<a name="_base.html-pyg.html-15"></a>                <span class="nt">&lt;header</span> <span class="na">id=</span><span class="s">&quot;header&quot;</span><span class="nt">&gt;</span>
<a name="_base.html-pyg.html-16"></a>                <span class="nt">&lt;div</span> <span class="na">class=</span><span class="s">&quot;5grid-layout&quot;</span><span class="nt">&gt;</span>
<a name="_base.html-pyg.html-17"></a>                    <span class="nt">&lt;div</span> <span class="na">id=</span><span class="s">&quot;menu&quot;</span><span class="nt">&gt;</span>
<a name="_base.html-pyg.html-18"></a>                        <span class="nt">&lt;nav</span> <span class="na">class=</span><span class="s">&quot;mobileUI-site-nav&quot;</span><span class="nt">&gt;</span>
<a name="_base.html-pyg.html-19"></a>                        {% block nav_menu -%}
<a name="_base.html-pyg.html-20"></a>                        {{ menu() }}
<a name="_base.html-pyg.html-21"></a>                        {% endblock -%}
<a name="_base.html-pyg.html-22"></a>                        <span class="nt">&lt;/nav&gt;</span>
<a name="_base.html-pyg.html-23"></a>                    <span class="nt">&lt;/div&gt;</span>
<a name="_base.html-pyg.html-24"></a>                <span class="nt">&lt;/div&gt;</span>
<a name="_base.html-pyg.html-25"></a>                {% block logo -%}
<a name="_base.html-pyg.html-26"></a>                {% include &#39;macros/_logo.html&#39; -%}
<a name="_base.html-pyg.html-27"></a>                {% endblock -%}
<a name="_base.html-pyg.html-28"></a>                <span class="nt">&lt;/header&gt;</span>
<a name="_base.html-pyg.html-29"></a>            <span class="nt">&lt;/div&gt;</span>
<a name="_base.html-pyg.html-30"></a>            {% block banner -%}
<a name="_base.html-pyg.html-31"></a>            {% include &#39;macros/_banner.html&#39; -%}
<a name="_base.html-pyg.html-32"></a>            <span class="nt">&lt;div</span> <span class="na">class=</span><span class="s">&quot;divider&quot;</span><span class="nt">&gt;&lt;/div&gt;</span>
<a name="_base.html-pyg.html-33"></a>            {% endblock -%}
<a name="_base.html-pyg.html-34"></a>            {% block mainpage -%}
<a name="_base.html-pyg.html-35"></a>            <span class="nt">&lt;div</span> <span class="na">id=</span><span class="s">&quot;page-wrapper&quot;</span><span class="nt">&gt;</span>
<a name="_base.html-pyg.html-36"></a>                {{ content }}
<a name="_base.html-pyg.html-37"></a>            <span class="nt">&lt;/div&gt;</span>
<a name="_base.html-pyg.html-38"></a>            {% endblock -%}
<a name="_base.html-pyg.html-39"></a>        <span class="nt">&lt;/div&gt;</span>
<a name="_base.html-pyg.html-40"></a>        {% block footer -%}
<a name="_base.html-pyg.html-41"></a>        {% include &#39;macros/_footer.html&#39; -%}
<a name="_base.html-pyg.html-42"></a>        {% endblock -%}
<a name="_base.html-pyg.html-43"></a>    <span class="nt">&lt;/div&gt;</span>
<a name="_base.html-pyg.html-44"></a><span class="nt">&lt;/body&gt;</span>
<a name="_base.html-pyg.html-45"></a><span class="nt">&lt;/html&gt;</span>
</pre></div>


We can break our layout into manageable sections by using jinja's include statements to insert snippets into our template, and by defining blocks we can use jinja's inheritance to customize these blocks in other templates. Here is our generic site-side `_template.html`

<div class="highlight"><pre><a name="_template.html-pyg.html-1"></a>{% extends &#39;_base.html&#39; -%}
<a name="_template.html-pyg.html-2"></a>
<a name="_template.html-pyg.html-3"></a>{% block banner -%}
<a name="_template.html-pyg.html-4"></a>{% endblock -%}
<a name="_template.html-pyg.html-5"></a>
<a name="_template.html-pyg.html-6"></a>{% block mainpage -%}
<a name="_template.html-pyg.html-7"></a><span class="nt">&lt;div</span> <span class="na">id=</span><span class="s">&quot;page-wrapper&quot;</span><span class="nt">&gt;</span>
<a name="_template.html-pyg.html-8"></a>    <span class="nt">&lt;div</span> <span class="na">class=</span><span class="s">&quot;divider&quot;</span><span class="nt">&gt;&lt;/div&gt;</span>
<a name="_template.html-pyg.html-9"></a>    <span class="nt">&lt;div</span> <span class="na">class=</span><span class="s">&quot;12u&quot;</span><span class="nt">&gt;</span>
<a name="_template.html-pyg.html-10"></a>        <span class="nt">&lt;div</span> <span class="na">class=</span><span class="s">&quot;5grid-layout&quot;</span> <span class="na">id=</span><span class="s">&quot;onecolumn&quot;</span><span class="nt">&gt;</span>
<a name="_template.html-pyg.html-11"></a>            <span class="nt">&lt;div</span> <span class="na">class=</span><span class="s">&quot;row&quot;</span><span class="nt">&gt;</span>
<a name="_template.html-pyg.html-12"></a>                <span class="nt">&lt;div</span> <span class="na">class=</span><span class="s">&quot;12u&quot;</span><span class="nt">&gt;</span>
<a name="_template.html-pyg.html-13"></a>                    <span class="nt">&lt;section&gt;</span>
<a name="_template.html-pyg.html-14"></a>                    <span class="nt">&lt;div</span> <span class="na">class=</span><span class="s">&quot;post&quot;</span><span class="nt">&gt;</span>
<a name="_template.html-pyg.html-15"></a>                        {{ content }}
<a name="_template.html-pyg.html-16"></a>                    <span class="nt">&lt;/div&gt;</span>
<a name="_template.html-pyg.html-17"></a>                    <span class="nt">&lt;/section&gt;</span>
<a name="_template.html-pyg.html-18"></a>                <span class="nt">&lt;/div&gt;</span>
<a name="_template.html-pyg.html-19"></a>            <span class="nt">&lt;/div&gt;</span>
<a name="_template.html-pyg.html-20"></a>        <span class="nt">&lt;/div&gt;</span>
<a name="_template.html-pyg.html-21"></a>    <span class="nt">&lt;/div&gt;</span>
<a name="_template.html-pyg.html-22"></a><span class="nt">&lt;/div&gt;</span>
<a name="_template.html-pyg.html-23"></a>{% endblock -%}
</pre></div>


And here is a custom template for the home page:

<div class="highlight"><pre><a name="_home_template.html-pyg.html-1"></a>{% extends &#39;_base.html&#39; -%}
<a name="_home_template.html-pyg.html-2"></a>{% block mainpage -%}
<a name="_home_template.html-pyg.html-3"></a><span class="nt">&lt;div</span> <span class="na">id=</span><span class="s">&quot;featured-content-wrapper&quot;</span><span class="nt">&gt;</span>
<a name="_home_template.html-pyg.html-4"></a>    <span class="nt">&lt;div</span> <span class="na">class=</span><span class="s">&quot;12u&quot;</span> <span class="na">id=</span><span class="s">&quot;feature-content&quot;</span><span class="nt">&gt;</span>
<a name="_home_template.html-pyg.html-5"></a>        <span class="nt">&lt;div</span> <span class="na">class=</span><span class="s">&quot;5grid-layout&quot;</span><span class="nt">&gt;</span>
<a name="_home_template.html-pyg.html-6"></a>            <span class="nt">&lt;div</span> <span class="na">class=</span><span class="s">&quot;row&quot;</span><span class="nt">&gt;</span>
<a name="_home_template.html-pyg.html-7"></a>                {{ content.one }}
<a name="_home_template.html-pyg.html-8"></a>            <span class="nt">&lt;/div&gt;</span>
<a name="_home_template.html-pyg.html-9"></a>        <span class="nt">&lt;/div&gt;</span>
<a name="_home_template.html-pyg.html-10"></a>    <span class="nt">&lt;/div&gt;</span>
<a name="_home_template.html-pyg.html-11"></a><span class="nt">&lt;/div&gt;</span>
<a name="_home_template.html-pyg.html-12"></a><span class="nt">&lt;div</span> <span class="na">id=</span><span class="s">&quot;page-wrapper&quot;</span><span class="nt">&gt;</span>
<a name="_home_template.html-pyg.html-13"></a>    <span class="nt">&lt;div</span> <span class="na">class=</span><span class="s">&quot;divider&quot;</span><span class="nt">&gt;&lt;/div&gt;</span>
<a name="_home_template.html-pyg.html-14"></a>    <span class="nt">&lt;div</span> <span class="na">class=</span><span class="s">&quot;12u&quot;</span><span class="nt">&gt;</span>
<a name="_home_template.html-pyg.html-15"></a>        <span class="nt">&lt;div</span> <span class="na">class=</span><span class="s">&quot;5grid-layout&quot;</span> <span class="na">id=</span><span class="s">&quot;page&quot;</span><span class="nt">&gt;</span>
<a name="_home_template.html-pyg.html-16"></a>            <span class="nt">&lt;div</span> <span class="na">class=</span><span class="s">&quot;row&quot;</span><span class="nt">&gt;</span>
<a name="_home_template.html-pyg.html-17"></a>                <span class="nt">&lt;div</span> <span class="na">class=</span><span class="s">&quot;7u&quot;</span><span class="nt">&gt;</span>
<a name="_home_template.html-pyg.html-18"></a>                    {{ content.two }}
<a name="_home_template.html-pyg.html-19"></a>
<a name="_home_template.html-pyg.html-20"></a>                <span class="nt">&lt;/div&gt;</span>
<a name="_home_template.html-pyg.html-21"></a>                <span class="nt">&lt;div</span> <span class="na">class=</span><span class="s">&quot;1u&quot;</span><span class="nt">&gt;</span><span class="ni">&amp;nbsp;</span><span class="nt">&lt;/div&gt;</span>
<a name="_home_template.html-pyg.html-22"></a>                <span class="nt">&lt;div</span> <span class="na">class=</span><span class="s">&quot;2u&quot;</span> <span class="na">id=</span><span class="s">&quot;sidebar1&quot;</span><span class="nt">&gt;</span>
<a name="_home_template.html-pyg.html-23"></a>                    {{ content.three }}
<a name="_home_template.html-pyg.html-24"></a>                <span class="nt">&lt;/div&gt;</span>
<a name="_home_template.html-pyg.html-25"></a>                <span class="nt">&lt;div</span> <span class="na">class=</span><span class="s">&quot;2u&quot;</span><span class="nt">&gt;</span>
<a name="_home_template.html-pyg.html-26"></a>                    {{ content.four }}
<a name="_home_template.html-pyg.html-27"></a>                <span class="nt">&lt;/div&gt;</span>
<a name="_home_template.html-pyg.html-28"></a>            <span class="nt">&lt;/div&gt;</span>
<a name="_home_template.html-pyg.html-29"></a>        <span class="nt">&lt;/div&gt;</span>
<a name="_home_template.html-pyg.html-30"></a>    <span class="nt">&lt;/div&gt;</span>
<a name="_home_template.html-pyg.html-31"></a><span class="nt">&lt;/div&gt;</span>
<a name="_home_template.html-pyg.html-32"></a>{% endblock -%}
</pre></div>


### Navigation and Meta Goodies

In addition to referencing the page content of the page the template is being applied to, the WebsiteReporter also generates helpers for site navigation and similar utilities.

We can see this in the navigation menu macro:

<div class="highlight"><pre><a name="macros--nav.jinja-pyg.html-1"></a><span class="cp">{%</span> <span class="k">macro</span> <span class="nv">menu</span><span class="o">()</span> <span class="cp">%}</span><span class="x"></span>
<a name="macros--nav.jinja-pyg.html-2"></a><span class="x">&lt;ul&gt;</span>
<a name="macros--nav.jinja-pyg.html-3"></a><span class="cp">{%</span> <span class="k">for</span> <span class="nv">dirname</span> <span class="k">in</span> <span class="nv">sorted</span><span class="o">(</span><span class="nv">navigation.directories</span><span class="o">[</span><span class="m">1</span><span class="o">])</span> -<span class="cp">%}</span><span class="x"></span>
<a name="macros--nav.jinja-pyg.html-4"></a><span class="cp">{%</span> <span class="k">set</span> <span class="nv">subdirs</span> <span class="o">=</span> <span class="nv">navigation.directories</span><span class="o">[</span><span class="m">1</span><span class="o">][</span><span class="nv">dirname</span><span class="o">]</span> -<span class="cp">%}</span><span class="x"></span>
<a name="macros--nav.jinja-pyg.html-5"></a>
<a name="macros--nav.jinja-pyg.html-6"></a><span class="cp">{%</span> <span class="k">if</span> <span class="nv">navigation.current_index</span> <span class="o">==</span> <span class="nv">dirname</span> -<span class="cp">%}</span><span class="x"></span>
<a name="macros--nav.jinja-pyg.html-7"></a><span class="cp">{%</span> <span class="k">set</span> <span class="nv">liclass</span> <span class="o">=</span> <span class="s1">&#39;active&#39;</span> -<span class="cp">%}</span><span class="x"></span>
<a name="macros--nav.jinja-pyg.html-8"></a><span class="cp">{%</span> <span class="k">else</span> -<span class="cp">%}</span><span class="x"></span>
<a name="macros--nav.jinja-pyg.html-9"></a><span class="cp">{%</span> <span class="k">set</span> <span class="nv">liclass</span> <span class="o">=</span> <span class="s1">&#39;&#39;</span> -<span class="cp">%}</span><span class="x"></span>
<a name="macros--nav.jinja-pyg.html-10"></a><span class="cp">{%</span> <span class="k">endif</span> -<span class="cp">%}</span><span class="x"></span>
<a name="macros--nav.jinja-pyg.html-11"></a>
<a name="macros--nav.jinja-pyg.html-12"></a><span class="x">&lt;li class=&quot;</span><span class="cp">{{</span> <span class="nv">liclass</span> <span class="cp">}}</span><span class="x">&quot;&gt;&lt;a href=&quot;/</span><span class="cp">{{</span> <span class="nv">dirname</span> <span class="cp">}}</span><span class="x">&quot;&gt;</span><span class="cp">{{</span> <span class="nv">dirname.capitalize</span><span class="o">()</span> <span class="cp">}}</span><span class="x">&lt;/a&gt;&lt;/li&gt;</span>
<a name="macros--nav.jinja-pyg.html-13"></a><span class="cp">{%</span> <span class="k">endfor</span> -<span class="cp">%}</span><span class="x"></span>
<a name="macros--nav.jinja-pyg.html-14"></a>
<a name="macros--nav.jinja-pyg.html-15"></a>
<a name="macros--nav.jinja-pyg.html-16"></a><span class="cp">{%</span> <span class="k">endmacro</span> <span class="cp">%}</span><span class="x"></span>
</pre></div>


Here is a page showing all the objects which are available to WebsiteReporter templates:

[link to page which introspects on other stuff](introspect.html)